@@ -3,7 +3,7 @@
  * This code is part of GOsa (http://www.gosa-project.org)
  * Copyright (C) 2003-2008 GONICUS GmbH
  *
- * ID: $$Id: main.php 20708 2011-04-12 08:41:49Z hickert $$
+ * ID: $$Id: main.php 20959 2011-07-27 07:43:19Z hickert $$
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -163,7 +163,7 @@ if (!session::global_is_set('plist')){
   /* Initially load all classes */
   $class_list= get_declared_classes();
   foreach ($class_mapping as $class => $path){
-    if (!in_array($class, $class_list)){
+    if (!in_array_strict($class, $class_list)){
       if (is_readable("$BASE_DIR/$path")){
         require_once("$BASE_DIR/$path");
       } else {
